==> cdktf-cdktf-provider-docker-0.0.30.tar.gz: package/lib/docker-provider.d.ts <==
import { Construct } from 'constructs';
import { TerraformProvider } from 'cdktf';
/**
 *
 */
export interface DockerProviderConfig {
    /**
     * PEM-encoded content of Docker host CA certificate.
     */
    readonly caMaterial?: string;
    /**
     * PEM-encoded content of Docker client certificate.
     */
    readonly certMaterial?: string;
    /**
     * Path to directory with Docker TLS config.
     */
    readonly certPath?: string;
    /**
     * The Docker daemon address.
     */
    readonly host?: string;
    /**
     * PEM-encoded content of Docker client private key.
     */
    readonly keyMaterial?: string;
    /**
     * Alias name.
     */
    readonly alias?: string;
    /**
     * registry_auth block.
     */
    readonly registryAuth?: DockerProviderRegistryAuth[];
}
/**
 *
 */
export interface DockerProviderRegistryAuth {
    /**
     * Address of the registry.
     */
    readonly address: string;
    /**
     * Path to docker json file for registry auth.
     */
    readonly configFile?: string;
    /**
     * Plain content of the docker json file for registry auth.
     */
    readonly configFileContent?: string;
    /**
     * Password for the registry.
     */
    readonly password?: string;
    /**
     * Username for the registry.
     */
    readonly username?: string;
}
/**
 *
 */
export declare class DockerProvider extends TerraformProvider {
    /**
     *
     */
    constructor(scope: Construct, id: string, config?: DockerProviderConfig);
    private _caMaterial?;
    /**
     *
     */
    get caMaterial(): string | undefined;
    /**
     *
     */
    set caMaterial(value: string | undefined);
    private _certMaterial?;
    /**
     *
     */
    get certMaterial(): string | undefined;
    /**
     *
     */
    set certMaterial(value: string | undefined);
    private _certPath?;
    /**
     *
     */
    get certPath(): string | undefined;
    /**
     *
     */
    set certPath(value: string | undefined);
    private _host?;
    /**
     *
     */
    get host(): string | undefined;
    /**
     *
     */
    set host(value: string | undefined);
    private _keyMaterial?;
    /**
     *
     */
    get keyMaterial(): string | undefined;
    /**
     *
     */
    set keyMaterial(value: string | undefined);
    private _alias?;
    /**
     *
     */
    get alias(): string | undefined;
    /**
     *
     */
    set alias(value: string | undefined);
    private _registryAuth?;
    /**
     *
     */
    get registryAuth(): DockerProviderRegistryAuth[] | undefined;
    /**
     *
     */
    set registryAuth(value: DockerProviderRegistryAuth[] | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-docker-0.0.64.tar.gz: package/lib/docker-provider.d.ts <==
import { Construct } from 'constructs';
import { TerraformProvider } from 'cdktf';
/**
 * @stability stable
 */
export interface DockerProviderConfig {
    /**
     * PEM-encoded content of Docker host CA certificate.
     *
     * @stability stable
     */
    readonly caMaterial?: string;
    /**
     * PEM-encoded content of Docker client certificate.
     *
     * @stability stable
     */
    readonly certMaterial?: string;
    /**
     * Path to directory with Docker TLS config.
     *
     * @stability stable
     */
    readonly certPath?: string;
    /**
     * The Docker daemon address.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * PEM-encoded content of Docker client private key.
     *
     * @stability stable
     */
    readonly keyMaterial?: string;
    /**
     * Alias name.
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * registry_auth block.
     *
     * @stability stable
     */
    readonly registryAuth?: DockerProviderRegistryAuth[];
}
/**
 * @stability stable
 */
export interface DockerProviderRegistryAuth {
    /**
     * Address of the registry.
     *
     * @stability stable
     */
    readonly address: string;
    /**
     * Path to docker json file for registry auth.
     *
     * @stability stable
     */
    readonly configFile?: string;
    /**
     * Plain content of the docker json file for registry auth.
     *
     * @stability stable
     */
    readonly configFileContent?: string;
    /**
     * Password for the registry.
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * Username for the registry.
     *
     * @stability stable
     */
    readonly username?: string;
}
/**
 * @stability stable
 */
export declare class DockerProvider extends TerraformProvider {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DockerProviderConfig);
    private _caMaterial?;
    /**
     * @stability stable
     */
    get caMaterial(): string | undefined;
    /**
     * @stability stable
     */
    set caMaterial(value: string | undefined);
    /**
     * @stability stable
     */
    resetCaMaterial(): void;
    /**
     * @stability stable
     */
    get caMaterialInput(): string | undefined;
    private _certMaterial?;
    /**
     * @stability stable
     */
    get certMaterial(): string | undefined;
    /**
     * @stability stable
     */
    set certMaterial(value: string | undefined);
    /**
     * @stability stable
     */
    resetCertMaterial(): void;
    /**
     * @stability stable
     */
    get certMaterialInput(): string | undefined;
    private _certPath?;
    /**
     * @stability stable
     */
    get certPath(): string | undefined;
    /**
     * @stability stable
     */
    set certPath(value: string | undefined);
    /**
     * @stability stable
     */
    resetCertPath(): void;
    /**
     * @stability stable
     */
    get certPathInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string | undefined;
    /**
     * @stability stable
     */
    set host(value: string | undefined);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _keyMaterial?;
    /**
     * @stability stable
     */
    get keyMaterial(): string | undefined;
    /**
     * @stability stable
     */
    set keyMaterial(value: string | undefined);
    /**
     * @stability stable
     */
    resetKeyMaterial(): void;
    /**
     * @stability stable
     */
    get keyMaterialInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _registryAuth?;
    /**
     * @stability stable
     */
    get registryAuth(): DockerProviderRegistryAuth[] | undefined;
    /**
     * @stability stable
     */
    set registryAuth(value: DockerProviderRegistryAuth[] | undefined);
    /**
     * @stability stable
     */
    resetRegistryAuth(): void;
    /**
     * @stability stable
     */
    get registryAuthInput(): DockerProviderRegistryAuth[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
